@@ -64,13 +64,13 @@ pub struct Index {
     /// The origin of the index (e.g., a CLI flag, a user-level configuration file, etc.).
     #[serde(skip)]
     pub origin: Option<Origin>,
-    // /// The type of the index.
-    // ///
-    // /// Indexes can either be PEP 503-compliant (i.e., a registry implementing the Simple API) or
-    // /// structured as a flat list of distributions (e.g., `--find-links`). In both cases, indexes
-    // /// can point to either local or remote resources.
-    // #[serde(default)]
-    // pub r#type: IndexKind,
+    /// The format used by the index.
+    ///
+    /// Indexes can either be PEP 503-compliant (i.e., a PyPI-style registry implementing the Simple
+    /// API) or structured as a flat list of distributions (e.g., `--find-links`). In both cases,
+    /// indexes can point to either local or remote resources.
+    #[serde(default)]
+    pub format: IndexFormat,
     /// The URL of the upload endpoint.
     ///
     /// When using `uv publish --index <name>`, this URL is used for publishing.
@@ -96,17 +96,28 @@ pub struct Index {
     pub authenticate: AuthPolicy,
 }
 
-// #[derive(
-//     Default, Debug, Copy, Clone, Hash, Eq, PartialEq, serde::Serialize, serde::Deserialize,
-// )]
-// #[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
-// pub enum IndexKind {
-//     /// A PEP 503 and/or PEP 691-compliant index.
-//     #[default]
-//     Simple,
-//     /// An index containing a list of links to distributions (e.g., `--find-links`).
-//     Flat,
-// }
+#[derive(
+    Default,
+    Debug,
+    Copy,
+    Clone,
+    Hash,
+    Eq,
+    PartialEq,
+    Ord,
+    PartialOrd,
+    serde::Serialize,
+    serde::Deserialize,
+)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
+#[serde(rename_all = "kebab-case")]
+pub enum IndexFormat {
+    /// A PyPI-style index implementing the Simple Repository API.
+    #[default]
+    Simple,
+    /// A `--find-links`-style index containing a flat list of wheels and source distributions.
+    Flat,
+}
 
 impl Index {
     /// Initialize an [`Index`] from a pip-style `--index-url`.
@@ -117,6 +128,7 @@ impl Index {
             explicit: false,
             default: true,
             origin: None,
+            format: IndexFormat::Simple,
             publish_url: None,
             authenticate: AuthPolicy::default(),
         }
@@ -130,6 +142,7 @@ impl Index {
             explicit: false,
             default: false,
             origin: None,
+            format: IndexFormat::Simple,
             publish_url: None,
             authenticate: AuthPolicy::default(),
         }
@@ -143,6 +156,7 @@ impl Index {
             explicit: false,
             default: false,
             origin: None,
+            format: IndexFormat::Flat,
             publish_url: None,
             authenticate: AuthPolicy::default(),
         }
@@ -210,6 +224,7 @@ impl From<IndexUrl> for Index {
             explicit: false,
             default: false,
             origin: None,
+            format: IndexFormat::Simple,
             publish_url: None,
             authenticate: AuthPolicy::default(),
         }
@@ -231,6 +246,7 @@ impl FromStr for Index {
                     explicit: false,
                     default: false,
                     origin: None,
+                    format: IndexFormat::Simple,
                     publish_url: None,
                     authenticate: AuthPolicy::default(),
                 });
@@ -245,6 +261,7 @@ impl FromStr for Index {
             explicit: false,
             default: false,
             origin: None,
+            format: IndexFormat::Simple,
             publish_url: None,
             authenticate: AuthPolicy::default(),
         })
@@ -254,21 +271,17 @@ impl FromStr for Index {
 /// An [`IndexUrl`] along with the metadata necessary to query the index.
 #[derive(Debug, Clone, Hash, Eq, PartialEq, Ord, PartialOrd)]
 pub struct IndexMetadata {
+    /// The URL of the index.
     pub url: IndexUrl,
-    // /// The type of the index.
-    // ///
-    // /// Indexes can either be PEP 503-compliant (i.e., a registry implementing the Simple API) or
-    // /// structured as a flat list of distributions (e.g., `--find-links`). In both cases, indexes
-    // /// can point to either local or remote resources.
-    // #[serde(default)]
-    // pub r#type: IndexKind,
+    /// The format used by the index.
+    pub format: IndexFormat,
 }
 
 impl IndexMetadata {
     /// Return a reference to the [`IndexMetadata`].
     pub fn as_ref(&self) -> IndexMetadataRef<'_> {
-        let Self { url } = self;
-        IndexMetadataRef { url }
+        let Self { url, format: kind } = self;
+        IndexMetadataRef { url, format: *kind }
     }
 
     /// Consume the [`IndexMetadata`] and return the [`IndexUrl`].
@@ -280,7 +293,10 @@ impl IndexMetadata {
 /// A reference to an [`IndexMetadata`].
 #[derive(Debug, Copy, Clone)]
 pub struct IndexMetadataRef<'a> {
+    /// The URL of the index.
     pub url: &'a IndexUrl,
+    /// The format used by the index.
+    pub format: IndexFormat,
 }
 
 impl IndexMetadata {
@@ -297,27 +313,39 @@ impl IndexMetadataRef<'_> {
     }
 }
 
-impl<'a> From<&'a IndexMetadata> for IndexMetadataRef<'a> {
-    fn from(value: &'a IndexMetadata) -> Self {
-        Self { url: &value.url }
-    }
-}
-
-impl<'a> From<&'a IndexUrl> for IndexMetadataRef<'a> {
-    fn from(value: &'a IndexUrl) -> Self {
-        Self { url: value }
-    }
-}
-
 impl<'a> From<&'a Index> for IndexMetadataRef<'a> {
     fn from(value: &'a Index) -> Self {
-        Self { url: &value.url }
+        Self {
+            url: &value.url,
+            format: value.format,
+        }
+    }
+}
+
+impl<'a> From<&'a IndexMetadata> for IndexMetadataRef<'a> {
+    fn from(value: &'a IndexMetadata) -> Self {
+        Self {
+            url: &value.url,
+            format: value.format,
+        }
     }
 }
 
 impl From<IndexUrl> for IndexMetadata {
     fn from(value: IndexUrl) -> Self {
-        Self { url: value }
+        Self {
+            url: value,
+            format: IndexFormat::Simple,
+        }
+    }
+}
+
+impl<'a> From<&'a IndexUrl> for IndexMetadataRef<'a> {
+    fn from(value: &'a IndexUrl) -> Self {
+        Self {
+            url: value,
+            format: IndexFormat::Simple,
+        }
     }
 }
 
