@@ -177,7 +177,7 @@ impl PythonEnvironment {
                 }));
             }
             Err(err) => return Err(Error::Discovery(err.into())),
-        };
+        }
 
         if root.as_ref().is_file() {
             return Err(InvalidEnvironment {
@@ -211,7 +211,7 @@ impl PythonEnvironment {
                 kind: InvalidEnvironmentKind::MissingExecutable(executable.clone()),
             }
             .into());
-        };
+        }
 
         let interpreter = Interpreter::query(executable, cache)?;
 
@@ -355,4 +355,13 @@ impl PythonEnvironment {
                 .unwrap_or(false)
         }
     }
+
+    /// If this is a virtual environment (indicated by the presence of
+    /// a `pyvenv.cfg` file), this returns true if the `pyvenv.cfg` version
+    /// is the same as the interpreter Python version. Also returns true
+    /// if this is not a virtual environment.
+    pub fn matches_interpreter(&self, interpreter: &Interpreter) -> bool {
+        let Ok(cfg) = self.cfg() else { return true };
+        cfg.matches_interpreter(interpreter)
+    }
 }
