@@ -13,6 +13,8 @@ pub enum RequirementsSource {
     Package(RequirementsTxtRequirement),
     /// An editable path was provided on the command line (e.g., `pip install -e ../flask`).
     Editable(RequirementsTxtRequirement),
+    /// Dependencies were provided via a `pylock.toml` file.
+    PylockToml(PathBuf),
     /// Dependencies were provided via a `requirements.txt` file (e.g., `pip install -r requirements.txt`).
     RequirementsTxt(PathBuf),
     /// Dependencies were provided via a `pyproject.toml` file (e.g., `pip-compile pyproject.toml`).
@@ -23,6 +25,8 @@ pub enum RequirementsSource {
     SetupCfg(PathBuf),
     /// Dependencies were provided via a path to a source tree (e.g., `pip install .`).
     SourceTree(PathBuf),
+    /// Dependencies were provided via an unsupported Conda `environment.yml` file (e.g., `pip install -r environment.yml`).
+    EnvironmentYml(PathBuf),
 }
 
 impl RequirementsSource {
@@ -35,6 +39,13 @@ impl RequirementsSource {
             Self::SetupPy(path)
         } else if path.ends_with("setup.cfg") {
             Self::SetupCfg(path)
+        } else if path.ends_with("environment.yml") {
+            Self::EnvironmentYml(path)
+        } else if path
+            .file_name()
+            .is_some_and(|file_name| file_name.to_str().is_some_and(is_pylock_toml))
+        {
+            Self::PylockToml(path)
         } else {
             Self::RequirementsTxt(path)
         }
@@ -42,12 +53,20 @@ impl RequirementsSource {
 
     /// Parse a [`RequirementsSource`] from a `requirements.txt` file.
     pub fn from_requirements_txt(path: PathBuf) -> Self {
-        for filename in ["pyproject.toml", "setup.py", "setup.cfg"] {
-            if path.ends_with(filename) {
+        for file_name in ["pyproject.toml", "setup.py", "setup.cfg"] {
+            if path.ends_with(file_name) {
                 warn_user!(
                     "The file `{}` appears to be a `{}` file, but requirements must be specified in `requirements.txt` format.",
                     path.user_display(),
-                    filename
+                    file_name
+                );
+            }
+        }
+        if let Some(file_name) = path.file_name() {
+            if file_name.to_str().is_some_and(is_pylock_toml) {
+                warn_user!(
+                    "The file `{}` appears to be a `pylock.toml` file, but requirements must be specified in `requirements.txt` format.",
+                    path.user_display(),
                 );
             }
         }
@@ -56,12 +75,20 @@ impl RequirementsSource {
 
     /// Parse a [`RequirementsSource`] from a `constraints.txt` file.
     pub fn from_constraints_txt(path: PathBuf) -> Self {
-        for filename in ["pyproject.toml", "setup.py", "setup.cfg"] {
-            if path.ends_with(filename) {
+        for file_name in ["pyproject.toml", "setup.py", "setup.cfg"] {
+            if path.ends_with(file_name) {
                 warn_user!(
                     "The file `{}` appears to be a `{}` file, but constraints must be specified in `requirements.txt` format.",
                     path.user_display(),
-                    filename
+                    file_name
+                );
+            }
+        }
+        if let Some(file_name) = path.file_name() {
+            if file_name.to_str().is_some_and(is_pylock_toml) {
+                warn_user!(
+                    "The file `{}` appears to be a `pylock.toml` file, but constraints must be specified in `requirements.txt` format.",
+                    path.user_display(),
                 );
             }
         }
@@ -70,12 +97,20 @@ impl RequirementsSource {
 
     /// Parse a [`RequirementsSource`] from an `overrides.txt` file.
     pub fn from_overrides_txt(path: PathBuf) -> Self {
-        for filename in ["pyproject.toml", "setup.py", "setup.cfg"] {
-            if path.ends_with(filename) {
+        for file_name in ["pyproject.toml", "setup.py", "setup.cfg"] {
+            if path.ends_with(file_name) {
                 warn_user!(
                     "The file `{}` appears to be a `{}` file, but overrides must be specified in `requirements.txt` format.",
                     path.user_display(),
-                    filename
+                    file_name
+                );
+            }
+        }
+        if let Some(file_name) = path.file_name() {
+            if file_name.to_str().is_some_and(is_pylock_toml) {
+                warn_user!(
+                    "The file `{}` appears to be a `pylock.toml` file, but overrides must be specified in `requirements.txt` format.",
+                    path.user_display(),
                 );
             }
         }
@@ -106,7 +141,10 @@ impl RequirementsSource {
 
         // Similarly, if the user provided a `pyproject.toml` file without `-r` (as in
         // `uv pip install pyproject.toml`), prompt them to correct it.
-        if (name == "pyproject.toml" || name == "setup.py" || name == "setup.cfg")
+        if (name == "pyproject.toml"
+            || name == "setup.py"
+            || name == "setup.cfg"
+            || is_pylock_toml(name))
             && Path::new(&name).is_file()
         {
             let term = Term::stderr();
@@ -151,7 +189,10 @@ impl RequirementsSource {
 
         // Similarly, if the user provided a `pyproject.toml` file without `--with-requirements` (as in
         // `uvx --with pyproject.toml ruff`), prompt them to correct it.
-        if (name == "pyproject.toml" || name == "setup.py" || name == "setup.cfg")
+        if (name == "pyproject.toml"
+            || name == "setup.py"
+            || name == "setup.cfg"
+            || is_pylock_toml(name))
             && Path::new(&name).is_file()
         {
             let term = Term::stderr();
@@ -213,13 +254,21 @@ impl std::fmt::Display for RequirementsSource {
         match self {
             Self::Package(package) => write!(f, "{package:?}"),
             Self::Editable(path) => write!(f, "-e {path:?}"),
-            Self::RequirementsTxt(path)
+            Self::PylockToml(path)
+            | Self::RequirementsTxt(path)
             | Self::PyprojectToml(path)
             | Self::SetupPy(path)
             | Self::SetupCfg(path)
+            | Self::EnvironmentYml(path)
             | Self::SourceTree(path) => {
                 write!(f, "{}", path.simplified_display())
             }
         }
     }
 }
+
+/// Returns `true` if a file name matches the `pylock.toml` pattern defined in PEP 751.
+#[allow(clippy::case_sensitive_file_extension_comparisons)]
+pub fn is_pylock_toml(file_name: &str) -> bool {
+    file_name.starts_with("pylock.") && file_name.ends_with(".toml")
+}
