@@ -40,7 +40,7 @@ use uv_scripts::{Pep723ItemRef, Pep723Metadata, Pep723Script};
 use uv_settings::PythonInstallMirrors;
 use uv_types::{BuildIsolation, HashStrategy};
 use uv_warnings::warn_user_once;
-use uv_workspace::pyproject::{DependencyType, Source, SourceError};
+use uv_workspace::pyproject::{DependencyType, Source, SourceError, Sources, ToolUvSources};
 use uv_workspace::pyproject_mut::{ArrayEdit, DependencyTarget, PyProjectTomlMut};
 use uv_workspace::{DiscoveryOptions, VirtualProject, Workspace, WorkspaceCache};
 
@@ -438,166 +438,19 @@ pub(crate) async fn add(
             DependencyTarget::PyProjectToml,
         ),
     }?;
-    let mut edits = Vec::<DependencyEdit>::with_capacity(requirements.len());
-    for mut requirement in requirements {
-        // Add the specified extras.
-        let mut ex = requirement.extras.to_vec();
-        ex.extend(extras.iter().cloned());
-        ex.sort_unstable();
-        ex.dedup();
-        requirement.extras = ex.into_boxed_slice();
-
-        let (requirement, source) = match target {
-            AddTarget::Script(_, _) | AddTarget::Project(_, _) if raw_sources => {
-                (uv_pep508::Requirement::from(requirement), None)
-            }
-            AddTarget::Script(ref script, _) => {
-                let script_path = std::path::absolute(&script.path)?;
-                let script_dir = script_path.parent().expect("script path has no parent");
-                resolve_requirement(
-                    requirement,
-                    false,
-                    editable,
-                    index.cloned(),
-                    rev.clone(),
-                    tag.clone(),
-                    branch.clone(),
-                    script_dir,
-                )?
-            }
-            AddTarget::Project(ref project, _) => {
-                let workspace = project
-                    .workspace()
-                    .packages()
-                    .contains_key(&requirement.name);
-                resolve_requirement(
-                    requirement,
-                    workspace,
-                    editable,
-                    index.cloned(),
-                    rev.clone(),
-                    tag.clone(),
-                    branch.clone(),
-                    project.root(),
-                )?
-            }
-        };
-
-        // Redact any credentials. By default, we avoid writing sensitive credentials to files that
-        // will be checked into version control (e.g., `pyproject.toml` and `uv.lock`). Instead,
-        // we store the credentials in a global store, and reuse them during resolution. The
-        // expectation is that subsequent resolutions steps will succeed by reading from (e.g.) the
-        // user's credentials store, rather than by reading from the `pyproject.toml` file.
-        let source = match source {
-            Some(Source::Git {
-                mut git,
-                subdirectory,
-                rev,
-                tag,
-                branch,
-                marker,
-                extra,
-                group,
-            }) => {
-                let credentials = uv_auth::Credentials::from_url(&git);
-                if let Some(credentials) = credentials {
-                    debug!("Caching credentials for: {git}");
-                    GIT_STORE.insert(RepositoryUrl::new(&git), credentials);
-
-                    // Redact the credentials.
-                    redact_credentials(&mut git);
-                };
-                Some(Source::Git {
-                    git,
-                    subdirectory,
-                    rev,
-                    tag,
-                    branch,
-                    marker,
-                    extra,
-                    group,
-                })
-            }
-            _ => source,
-        };
-
-        // Determine the dependency type.
-        let dependency_type = match &dependency_type {
-            DependencyType::Dev => {
-                let existing = toml.find_dependency(&requirement.name, None);
-                if existing.iter().any(|dependency_type| matches!(dependency_type, DependencyType::Group(group) if group == &*DEV_DEPENDENCIES)) {
-                    // If the dependency already exists in `dependency-groups.dev`, use that.
-                    DependencyType::Group(DEV_DEPENDENCIES.clone())
-                } else if existing.iter().any(|dependency_type| matches!(dependency_type, DependencyType::Dev)) {
-                    // If the dependency already exists in `dev-dependencies`, use that.
-                    DependencyType::Dev
-                } else {
-                    // Otherwise, use `dependency-groups.dev`, unless it would introduce a separate table.
-                    match (toml.has_dev_dependencies(), toml.has_dependency_group(&DEV_DEPENDENCIES)) {
-                        (true, false) => DependencyType::Dev,
-                        (false, true) => DependencyType::Group(DEV_DEPENDENCIES.clone()),
-                        (true, true) => DependencyType::Group(DEV_DEPENDENCIES.clone()),
-                        (false, false) => DependencyType::Group(DEV_DEPENDENCIES.clone()),
-                    }
-                }
-            }
-            DependencyType::Group(group) if group == &*DEV_DEPENDENCIES => {
-                let existing = toml.find_dependency(&requirement.name, None);
-                if existing.iter().any(|dependency_type| matches!(dependency_type, DependencyType::Group(group) if group == &*DEV_DEPENDENCIES)) {
-                    // If the dependency already exists in `dependency-groups.dev`, use that.
-                    DependencyType::Group(DEV_DEPENDENCIES.clone())
-                } else if existing.iter().any(|dependency_type| matches!(dependency_type, DependencyType::Dev)) {
-                    // If the dependency already exists in `dev-dependencies`, use that.
-                    DependencyType::Dev
-                } else {
-                    // Otherwise, use `dependency-groups.dev`.
-                    DependencyType::Group(DEV_DEPENDENCIES.clone())
-                }
-            }
-            DependencyType::Production => DependencyType::Production,
-            DependencyType::Optional(extra) => DependencyType::Optional(extra.clone()),
-            DependencyType::Group(group) => DependencyType::Group(group.clone()),
-        };
-
-        // Update the `pyproject.toml`.
-        let edit = match &dependency_type {
-            DependencyType::Production => toml.add_dependency(&requirement, source.as_ref())?,
-            DependencyType::Dev => toml.add_dev_dependency(&requirement, source.as_ref())?,
-            DependencyType::Optional(ref extra) => {
-                toml.add_optional_dependency(extra, &requirement, source.as_ref())?
-            }
-            DependencyType::Group(ref group) => {
-                toml.add_dependency_group_requirement(group, &requirement, source.as_ref())?
-            }
-        };
-
-        // If the edit was inserted before the end of the list, update the existing edits.
-        if let ArrayEdit::Add(index) = &edit {
-            for edit in &mut edits {
-                if edit.dependency_type == dependency_type {
-                    match &mut edit.edit {
-                        ArrayEdit::Add(existing) => {
-                            if *existing >= *index {
-                                *existing += 1;
-                            }
-                        }
-                        ArrayEdit::Update(existing) => {
-                            if *existing >= *index {
-                                *existing += 1;
-                            }
-                        }
-                    }
-                }
-            }
-        }
-
-        edits.push(DependencyEdit {
-            dependency_type,
-            requirement,
-            source,
-            edit,
-        });
-    }
+    let edits = edits(
+        requirements,
+        &target,
+        editable,
+        &dependency_type,
+        raw_sources,
+        rev.as_deref(),
+        tag.as_deref(),
+        branch.as_deref(),
+        &extras,
+        index,
+        &mut toml,
+    )?;
 
     // Add any indexes that were provided on the command-line, in priority order.
     if !raw_sources {
@@ -692,6 +545,193 @@ pub(crate) async fn add(
     }
 }
 
+fn edits(
+    requirements: Vec<Requirement>,
+    target: &AddTarget,
+    editable: Option<bool>,
+    dependency_type: &DependencyType,
+    raw_sources: bool,
+    rev: Option<&str>,
+    tag: Option<&str>,
+    branch: Option<&str>,
+    extras: &[ExtraName],
+    index: Option<&IndexName>,
+    toml: &mut PyProjectTomlMut,
+) -> Result<Vec<DependencyEdit>> {
+    let mut edits = Vec::<DependencyEdit>::with_capacity(requirements.len());
+    for mut requirement in requirements {
+        // Add the specified extras.
+        let mut ex = requirement.extras.to_vec();
+        ex.extend(extras.iter().cloned());
+        ex.sort_unstable();
+        ex.dedup();
+        requirement.extras = ex.into_boxed_slice();
+
+        let (requirement, source) = match target {
+            AddTarget::Script(_, _) | AddTarget::Project(_, _) if raw_sources => {
+                (uv_pep508::Requirement::from(requirement), None)
+            }
+            AddTarget::Script(ref script, _) => {
+                let script_path = std::path::absolute(&script.path)?;
+                let script_dir = script_path.parent().expect("script path has no parent");
+
+                let existing_sources = Some(script.sources());
+                resolve_requirement(
+                    requirement,
+                    false,
+                    editable,
+                    index.cloned(),
+                    rev.map(ToString::to_string),
+                    tag.map(ToString::to_string),
+                    branch.map(ToString::to_string),
+                    script_dir,
+                    existing_sources,
+                )?
+            }
+            AddTarget::Project(ref project, _) => {
+                let existing_sources = project
+                    .pyproject_toml()
+                    .tool
+                    .as_ref()
+                    .and_then(|tool| tool.uv.as_ref())
+                    .and_then(|uv| uv.sources.as_ref())
+                    .map(ToolUvSources::inner);
+                let workspace = project
+                    .workspace()
+                    .packages()
+                    .contains_key(&requirement.name);
+                resolve_requirement(
+                    requirement,
+                    workspace,
+                    editable,
+                    index.cloned(),
+                    rev.map(ToString::to_string),
+                    tag.map(ToString::to_string),
+                    branch.map(ToString::to_string),
+                    project.root(),
+                    existing_sources,
+                )?
+            }
+        };
+
+        // Redact any credentials. By default, we avoid writing sensitive credentials to files that
+        // will be checked into version control (e.g., `pyproject.toml` and `uv.lock`). Instead,
+        // we store the credentials in a global store, and reuse them during resolution. The
+        // expectation is that subsequent resolutions steps will succeed by reading from (e.g.) the
+        // user's credentials store, rather than by reading from the `pyproject.toml` file.
+        let source = match source {
+            Some(Source::Git {
+                mut git,
+                subdirectory,
+                rev,
+                tag,
+                branch,
+                marker,
+                extra,
+                group,
+            }) => {
+                let credentials = uv_auth::Credentials::from_url(&git);
+                if let Some(credentials) = credentials {
+                    debug!("Caching credentials for: {git}");
+                    GIT_STORE.insert(RepositoryUrl::new(&git), credentials);
+
+                    // Redact the credentials.
+                    redact_credentials(&mut git);
+                }
+                Some(Source::Git {
+                    git,
+                    subdirectory,
+                    rev,
+                    tag,
+                    branch,
+                    marker,
+                    extra,
+                    group,
+                })
+            }
+            _ => source,
+        };
+
+        // Determine the dependency type.
+        let dependency_type = match &dependency_type {
+            DependencyType::Dev => {
+                let existing = toml.find_dependency(&requirement.name, None);
+                if existing.iter().any(|dependency_type| matches!(dependency_type, DependencyType::Group(group) if group == &*DEV_DEPENDENCIES)) {
+                    // If the dependency already exists in `dependency-groups.dev`, use that.
+                    DependencyType::Group(DEV_DEPENDENCIES.clone())
+                } else if existing.iter().any(|dependency_type| matches!(dependency_type, DependencyType::Dev)) {
+                    // If the dependency already exists in `dev-dependencies`, use that.
+                    DependencyType::Dev
+                } else {
+                    // Otherwise, use `dependency-groups.dev`, unless it would introduce a separate table.
+                    match (toml.has_dev_dependencies(), toml.has_dependency_group(&DEV_DEPENDENCIES)) {
+                        (true, false) => DependencyType::Dev,
+                        (false, true) => DependencyType::Group(DEV_DEPENDENCIES.clone()),
+                        (true, true) => DependencyType::Group(DEV_DEPENDENCIES.clone()),
+                        (false, false) => DependencyType::Group(DEV_DEPENDENCIES.clone()),
+                    }
+                }
+            }
+            DependencyType::Group(group) if group == &*DEV_DEPENDENCIES => {
+                let existing = toml.find_dependency(&requirement.name, None);
+                if existing.iter().any(|dependency_type| matches!(dependency_type, DependencyType::Group(group) if group == &*DEV_DEPENDENCIES)) {
+                    // If the dependency already exists in `dependency-groups.dev`, use that.
+                    DependencyType::Group(DEV_DEPENDENCIES.clone())
+                } else if existing.iter().any(|dependency_type| matches!(dependency_type, DependencyType::Dev)) {
+                    // If the dependency already exists in `dev-dependencies`, use that.
+                    DependencyType::Dev
+                } else {
+                    // Otherwise, use `dependency-groups.dev`.
+                    DependencyType::Group(DEV_DEPENDENCIES.clone())
+                }
+            }
+            DependencyType::Production => DependencyType::Production,
+            DependencyType::Optional(extra) => DependencyType::Optional(extra.clone()),
+            DependencyType::Group(group) => DependencyType::Group(group.clone()),
+        };
+
+        // Update the `pyproject.toml`.
+        let edit = match &dependency_type {
+            DependencyType::Production => toml.add_dependency(&requirement, source.as_ref())?,
+            DependencyType::Dev => toml.add_dev_dependency(&requirement, source.as_ref())?,
+            DependencyType::Optional(ref extra) => {
+                toml.add_optional_dependency(extra, &requirement, source.as_ref())?
+            }
+            DependencyType::Group(ref group) => {
+                toml.add_dependency_group_requirement(group, &requirement, source.as_ref())?
+            }
+        };
+
+        // If the edit was inserted before the end of the list, update the existing edits.
+        if let ArrayEdit::Add(index) = &edit {
+            for edit in &mut edits {
+                if edit.dependency_type == dependency_type {
+                    match &mut edit.edit {
+                        ArrayEdit::Add(existing) => {
+                            if *existing >= *index {
+                                *existing += 1;
+                            }
+                        }
+                        ArrayEdit::Update(existing) => {
+                            if *existing >= *index {
+                                *existing += 1;
+                            }
+                        }
+                    }
+                }
+            }
+        }
+
+        edits.push(DependencyEdit {
+            dependency_type,
+            requirement,
+            source,
+            edit,
+        });
+    }
+    Ok(edits)
+}
+
 /// Re-lock and re-sync the project after a series of edits.
 #[allow(clippy::fn_params_excessive_bools)]
 async fn lock_and_sync(
@@ -790,20 +830,7 @@ async fn lock_and_sync(
             // For example, convert `1.2.3+local` to `1.2.3`.
             let minimum = (*minimum).clone().without_local();
 
-            match edit.dependency_type {
-                DependencyType::Production => {
-                    toml.set_dependency_minimum_version(*index, minimum)?;
-                }
-                DependencyType::Dev => {
-                    toml.set_dev_dependency_minimum_version(*index, minimum)?;
-                }
-                DependencyType::Optional(ref extra) => {
-                    toml.set_optional_dependency_minimum_version(extra, *index, minimum)?;
-                }
-                DependencyType::Group(ref group) => {
-                    toml.set_dependency_group_requirement_minimum_version(group, *index, minimum)?;
-                }
-            }
+            toml.set_dependency_minimum_version(&edit.dependency_type, *index, minimum)?;
 
             modified = true;
         }
@@ -1010,6 +1037,7 @@ fn resolve_requirement(
     tag: Option<String>,
     branch: Option<String>,
     root: &Path,
+    existing_sources: Option<&BTreeMap<PackageName, Sources>>,
 ) -> Result<(uv_pep508::Requirement, Option<Source>), anyhow::Error> {
     let result = Source::from_requirement(
         &requirement.name,
@@ -1021,6 +1049,7 @@ fn resolve_requirement(
         tag,
         branch,
         root,
+        existing_sources,
     );
 
     let source = match result {
