@@ -5,7 +5,7 @@ use std::path::{Path, PathBuf};
 use std::process::{Command, Stdio};
 use std::str::FromStr;
 
-use tracing::{debug, warn};
+use tracing::{debug, trace, warn};
 use uv_cache::Cache;
 use uv_cli::AuthorFrom;
 use uv_client::BaseClientBuilder;
@@ -370,11 +370,7 @@ async fn init_project(
         // This can be arbitrary, i.e., not a version — in which case we may need to resolve the
         // interpreter
         match python_request {
-            PythonRequest::Version(VersionRequest::MajorMinor(
-                major,
-                minor,
-                PythonVariant::Default,
-            )) => {
+            PythonRequest::Version(VersionRequest::MajorMinor(major, minor, variant)) => {
                 let requires_python = RequiresPython::greater_than_equal_version(&Version::new([
                     u64::from(major),
                     u64::from(minor),
@@ -382,9 +378,7 @@ async fn init_project(
 
                 let python_request = if pin_python {
                     Some(PythonRequest::Version(VersionRequest::MajorMinor(
-                        major,
-                        minor,
-                        PythonVariant::Default,
+                        major, minor, variant,
                     )))
                 } else {
                     None
@@ -396,7 +390,7 @@ async fn init_project(
                 major,
                 minor,
                 patch,
-                PythonVariant::Default,
+                variant,
             )) => {
                 let requires_python = RequiresPython::greater_than_equal_version(&Version::new([
                     u64::from(major),
@@ -406,10 +400,7 @@ async fn init_project(
 
                 let python_request = if pin_python {
                     Some(PythonRequest::Version(VersionRequest::MajorMinorPatch(
-                        major,
-                        minor,
-                        patch,
-                        PythonVariant::Default,
+                        major, minor, patch, variant,
                     )))
                 } else {
                     None
@@ -417,8 +408,10 @@ async fn init_project(
 
                 (requires_python, python_request)
             }
-            ref
-            python_request @ PythonRequest::Version(VersionRequest::Range(ref specifiers, _)) => {
+            ref python_request @ PythonRequest::Version(VersionRequest::Range(
+                ref specifiers,
+                variant,
+            )) => {
                 let requires_python = RequiresPython::from_specifiers(specifiers);
 
                 let python_request = if pin_python {
@@ -439,7 +432,7 @@ async fn init_project(
                     Some(PythonRequest::Version(VersionRequest::MajorMinor(
                         interpreter.python_major(),
                         interpreter.python_minor(),
-                        PythonVariant::Default,
+                        variant,
                     )))
                 } else {
                     None
@@ -866,7 +859,7 @@ impl InitProjectKind {
         // Generate `src` files
         if !bare {
             generate_package_scripts(name, path, build_backend, true)?;
-        };
+        }
 
         // Initialize the version control system.
         init_vcs(path, vcs)?;
@@ -1136,7 +1129,7 @@ fn generate_package_scripts(
             let pyi_file = pkg_dir.join("_core.pyi");
             if !pyi_file.try_exists()? {
                 fs_err::write(pyi_file, pyi_contents)?;
-            };
+            }
             // Return python script calling binary
             binary_call_script
         }
@@ -1167,7 +1160,7 @@ fn generate_package_scripts(
             let pyi_file = pkg_dir.join("_core.pyi");
             if !pyi_file.try_exists()? {
                 fs_err::write(pyi_file, pyi_contents)?;
-            };
+            }
             // Return python script calling binary
             binary_call_script
         }
@@ -1191,52 +1184,98 @@ fn generate_package_scripts(
     Ok(())
 }
 
-/// Initialize the version control system at the given path.
+#[derive(Debug, Clone)]
+enum GitDiscoveryResult {
+    /// Git is initialized at the path.
+    Repository,
+    /// Git is not initialized at the path.
+    NoRepository,
+    /// There is no `git[.exe]` binary in PATH.
+    NoGit,
+    /// There is a `git[.exe]` binary in PATH, but it returned an unexpected output.
+    BrokenGit,
+}
+
+/// Checks if there is a Git work tree at the given path.
+fn detect_git_repository(path: &Path) -> GitDiscoveryResult {
+    // Determine whether the path is inside a Git work tree.
+    let Ok(git) = GIT.as_ref() else {
+        return GitDiscoveryResult::NoGit;
+    };
+    let Ok(output) = Command::new(git)
+        .arg("rev-parse")
+        .arg("--is-inside-work-tree")
+        .current_dir(path)
+        .output()
+    else {
+        debug!(
+            "`git rev-parse --is-inside-work-tree` failed to launch for `{}`",
+            path.display()
+        );
+        return GitDiscoveryResult::BrokenGit;
+    };
+    if output.status.success() {
+        if std::str::from_utf8(&output.stdout).map(str::trim) == Ok("true") {
+            debug!("Found a Git repository for `{}`", path.display());
+            GitDiscoveryResult::Repository
+        } else {
+            debug!(
+                "`git rev-parse --is-inside-work-tree` succeeded but didn't return `true` for `{}`",
+                path.display()
+            );
+            trace!(
+                "`git rev-parse --is-inside-work-tree` stdout: {:?}",
+                String::from_utf8_lossy(&output.stdout)
+            );
+            GitDiscoveryResult::BrokenGit
+        }
+    } else {
+        if std::str::from_utf8(&output.stderr).is_ok_and(|err| err.contains("not a git repository"))
+        {
+            debug!("Not a Git repository `{}`", path.display());
+            GitDiscoveryResult::NoRepository
+        } else {
+            debug!(
+                "`git rev-parse --is-inside-work-tree` failed but didn't contain `not a git repository` in stderr for `{}`",
+                path.display()
+            );
+            GitDiscoveryResult::BrokenGit
+        }
+    }
+}
+
+/// Initialize the version control system at the given path, if applicable.
 fn init_vcs(path: &Path, vcs: Option<VersionControlSystem>) -> Result<()> {
-    // Detect any existing version control system.
-    let existing = VersionControlSystem::detect(path);
-
-    let implicit = vcs.is_none();
-
-    let vcs = match (vcs, existing) {
-        // If no version control system was specified, and none was detected, default to Git.
-        (None, None) => VersionControlSystem::default(),
-        // If no version control system was specified, but a VCS was detected, leave it as-is.
-        (None, Some(existing)) => {
-            debug!("Detected existing version control system: {existing}");
-            VersionControlSystem::None
-        }
-        // If the user provides an explicit `--vcs none`,
-        (Some(VersionControlSystem::None), _) => VersionControlSystem::None,
-        // If a version control system was specified, use it.
-        (Some(vcs), None) => vcs,
-        // If a version control system was specified, but a VCS was detected...
-        (Some(vcs), Some(existing)) => {
-            // If they differ, raise an error.
-            if vcs != existing {
-                anyhow::bail!("The project is already in a version control system (`{existing}`); cannot initialize with `--vcs {vcs}`");
-            }
-
-            // Otherwise, ignore the specified VCS, since it's already in use.
-            VersionControlSystem::None
-        }
+    // vcs is None for an existing repository because we don't want to initialize again.
+    let (vcs, implicit) = match vcs {
+        None => match detect_git_repository(path) {
+            GitDiscoveryResult::NoRepository => (VersionControlSystem::Git, true),
+            GitDiscoveryResult::Repository
+            | GitDiscoveryResult::NoGit
+            | GitDiscoveryResult::BrokenGit => (VersionControlSystem::None, false),
+        },
+        Some(VersionControlSystem::None) => (VersionControlSystem::None, false),
+        // The user requested Git explicitly, so the only reason not to invoke it is that Git is
+        // already initialized. In case of an error (broken git), we will raise the real error
+        // when trying to initialize, which should give us a better error message.
+        Some(VersionControlSystem::Git) => match detect_git_repository(path) {
+            GitDiscoveryResult::NoRepository
+            | GitDiscoveryResult::BrokenGit
+            | GitDiscoveryResult::NoGit => (VersionControlSystem::Git, false),
+            GitDiscoveryResult::Repository => (VersionControlSystem::None, false),
+        },
     };
 
     // Attempt to initialize the VCS.
     match vcs.init(path) {
-        Ok(()) => (),
+        Ok(()) => Ok(()),
         // If the VCS isn't installed, only raise an error if a VCS was explicitly specified.
-        Err(err @ VersionControlError::GitNotInstalled) => {
-            if implicit {
-                debug!("Failed to initialize version control: {err}");
-            } else {
-                return Err(err.into());
-            }
+        Err(err @ VersionControlError::GitNotInstalled) if implicit => {
+            debug!("Failed to initialize version control: {err}");
+            Ok(())
         }
-        Err(err) => return Err(err.into()),
+        Err(err) => Err(err.into()),
     }
-
-    Ok(())
 }
 
 /// Try to get the author information.
