@@ -11,12 +11,12 @@ use uv_auth::UrlAuthPolicies;
 use uv_cache::Cache;
 use uv_client::{FlatIndexClient, RegistryClientBuilder};
 use uv_configuration::{
-    Concurrency, DependencyGroups, DependencyGroupsWithDefaults, DryRun, EditableMode,
+    Concurrency, Constraints, DependencyGroups, DependencyGroupsWithDefaults, DryRun, EditableMode,
     ExtrasSpecification, HashCheckingMode, InstallOptions, PreviewMode,
 };
 use uv_dispatch::BuildDispatch;
 use uv_distribution_types::{
-    DirectorySourceDist, Dist, Index, Resolution, ResolvedDist, SourceDist,
+    DirectorySourceDist, Dist, Index, Requirement, Resolution, ResolvedDist, SourceDist,
 };
 use uv_fs::Simplified;
 use uv_installer::SitePackages;
@@ -24,7 +24,7 @@ use uv_normalize::{DefaultGroups, PackageName};
 use uv_pep508::{MarkerTree, VersionOrUrl};
 use uv_pypi_types::{ParsedArchiveUrl, ParsedGitUrl, ParsedUrl};
 use uv_python::{PythonDownloads, PythonEnvironment, PythonPreference, PythonRequest};
-use uv_resolver::{FlatIndex, Installable};
+use uv_resolver::{FlatIndex, Installable, Lock};
 use uv_scripts::{Pep723ItemRef, Pep723Script};
 use uv_settings::PythonInstallMirrors;
 use uv_types::{BuildIsolation, HashStrategy};
@@ -274,12 +274,33 @@ pub(crate) async fn sync(
                 ));
             }
 
+            // Parse the requirements from the script.
             let spec = script_specification(Pep723ItemRef::Script(script), &settings.resolver)?
                 .unwrap_or_default();
+
+            // Parse the build constraints from the script.
+            let build_constraints = script
+                .metadata
+                .tool
+                .as_ref()
+                .and_then(|tool| {
+                    tool.uv
+                        .as_ref()
+                        .and_then(|uv| uv.build_constraint_dependencies.as_ref())
+                })
+                .map(|constraints| {
+                    Constraints::from_requirements(
+                        constraints
+                            .iter()
+                            .map(|constraint| Requirement::from(constraint.clone())),
+                    )
+                });
+
             match update_environment(
                 Deref::deref(&environment).clone(),
                 spec,
                 modifications,
+                build_constraints.unwrap_or_default(),
                 &settings,
                 &network_settings,
                 &PlatformState::default(),
@@ -327,7 +348,7 @@ pub(crate) async fn sync(
         SyncTarget::Script(script) => LockTarget::from(script),
     };
 
-    let lock = match LockOperation::new(
+    let outcome = match LockOperation::new(
         mode,
         &settings.resolver,
         &network_settings,
@@ -379,68 +400,24 @@ pub(crate) async fn sync(
                     }
                 }
             }
-            result.into_lock()
+            Outcome::Success(result.into_lock())
         }
         Err(ProjectError::Operation(err)) => {
             return diagnostics::OperationDiagnostic::native_tls(network_settings.native_tls)
                 .report(err)
                 .map_or(Ok(ExitStatus::Failure), |err| Err(err.into()))
         }
+        Err(ProjectError::LockMismatch(lock)) if dry_run.enabled() => {
+            // The lockfile is mismatched, but we're in dry-run mode. We should proceed with the
+            // sync operation, but exit with a non-zero status.
+            Outcome::LockMismatch(lock)
+        }
         Err(err) => return Err(err.into()),
     };
 
     // Identify the installation target.
-    let sync_target = match &target {
-        SyncTarget::Project(project) => {
-            match &project {
-                VirtualProject::Project(project) => {
-                    if all_packages {
-                        InstallTarget::Workspace {
-                            workspace: project.workspace(),
-                            lock: &lock,
-                        }
-                    } else if let Some(package) = package.as_ref() {
-                        InstallTarget::Project {
-                            workspace: project.workspace(),
-                            name: package,
-                            lock: &lock,
-                        }
-                    } else {
-                        // By default, install the root package.
-                        InstallTarget::Project {
-                            workspace: project.workspace(),
-                            name: project.project_name(),
-                            lock: &lock,
-                        }
-                    }
-                }
-                VirtualProject::NonProject(workspace) => {
-                    if all_packages {
-                        InstallTarget::NonProjectWorkspace {
-                            workspace,
-                            lock: &lock,
-                        }
-                    } else if let Some(package) = package.as_ref() {
-                        InstallTarget::Project {
-                            workspace,
-                            name: package,
-                            lock: &lock,
-                        }
-                    } else {
-                        // By default, install the entire workspace.
-                        InstallTarget::NonProjectWorkspace {
-                            workspace,
-                            lock: &lock,
-                        }
-                    }
-                }
-            }
-        }
-        SyncTarget::Script(script) => InstallTarget::Script {
-            script,
-            lock: &lock,
-        },
-    };
+    let sync_target =
+        identify_installation_target(&target, outcome.lock(), all_packages, package.as_ref());
 
     let state = state.fork();
 
@@ -475,7 +452,79 @@ pub(crate) async fn sync(
         Err(err) => return Err(err.into()),
     }
 
-    Ok(ExitStatus::Success)
+    match outcome {
+        Outcome::Success(..) => Ok(ExitStatus::Success),
+        Outcome::LockMismatch(lock) => Err(ProjectError::LockMismatch(lock).into()),
+    }
+}
+
+/// The outcome of a `lock` operation within a `sync` operation.
+#[derive(Debug)]
+enum Outcome {
+    /// The `lock` operation was successful.
+    Success(Lock),
+    /// The `lock` operation successfully resolved, but failed due to a mismatch (e.g., with `--locked`).
+    LockMismatch(Box<Lock>),
+}
+
+impl Outcome {
+    /// Return the [`Lock`] associated with this outcome.
+    fn lock(&self) -> &Lock {
+        match self {
+            Self::Success(lock) => lock,
+            Self::LockMismatch(lock) => lock,
+        }
+    }
+}
+
+fn identify_installation_target<'a>(
+    target: &'a SyncTarget,
+    lock: &'a Lock,
+    all_packages: bool,
+    package: Option<&'a PackageName>,
+) -> InstallTarget<'a> {
+    match &target {
+        SyncTarget::Project(project) => {
+            match &project {
+                VirtualProject::Project(project) => {
+                    if all_packages {
+                        InstallTarget::Workspace {
+                            workspace: project.workspace(),
+                            lock,
+                        }
+                    } else if let Some(package) = package {
+                        InstallTarget::Project {
+                            workspace: project.workspace(),
+                            name: package,
+                            lock,
+                        }
+                    } else {
+                        // By default, install the root package.
+                        InstallTarget::Project {
+                            workspace: project.workspace(),
+                            name: project.project_name(),
+                            lock,
+                        }
+                    }
+                }
+                VirtualProject::NonProject(workspace) => {
+                    if all_packages {
+                        InstallTarget::NonProjectWorkspace { workspace, lock }
+                    } else if let Some(package) = package {
+                        InstallTarget::Project {
+                            workspace,
+                            name: package,
+                            lock,
+                        }
+                    } else {
+                        // By default, install the entire workspace.
+                        InstallTarget::NonProjectWorkspace { workspace, lock }
+                    }
+                }
+            }
+        }
+        SyncTarget::Script(script) => InstallTarget::Script { script, lock },
+    }
 }
 
 #[derive(Debug, Clone)]
