@@ -42,10 +42,9 @@ fn help() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
-          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
-          --no-python-downloads  Disable automatic downloads of Python. [env:
-                                 "UV_PYTHON_DOWNLOADS=never"]
+      --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+      --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+      --no-python-downloads  Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet...
@@ -121,10 +120,9 @@ fn help_flag() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
-          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
-          --no-python-downloads  Disable automatic downloads of Python. [env:
-                                 "UV_PYTHON_DOWNLOADS=never"]
+      --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+      --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+      --no-python-downloads  Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet...
@@ -199,10 +197,9 @@ fn help_short_flag() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
-          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
-          --no-python-downloads  Disable automatic downloads of Python. [env:
-                                 "UV_PYTHON_DOWNLOADS=never"]
+      --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+      --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+      --no-python-downloads  Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet...
@@ -315,7 +312,7 @@ fn help_subcommand() {
               [env: UV_CACHE_DIR=]
 
     Python options:
-          --managed-python
+      --managed-python
               Require use of uv-managed Python versions.
               
               By default, uv prefers using Python versions it manages. However, it will use system
@@ -324,14 +321,14 @@ fn help_subcommand() {
               
               [env: UV_MANAGED_PYTHON=]
 
-          --no-managed-python
+      --no-managed-python
               Disable use of uv-managed Python versions.
               
               Instead, uv will search for a suitable Python version on the system.
               
               [env: UV_NO_MANAGED_PYTHON=]
 
-          --no-python-downloads
+      --no-python-downloads
               Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
@@ -568,7 +565,7 @@ fn help_subsubcommand() {
               [env: UV_CACHE_DIR=]
 
     Python options:
-          --managed-python
+      --managed-python
               Require use of uv-managed Python versions.
               
               By default, uv prefers using Python versions it manages. However, it will use system
@@ -577,14 +574,14 @@ fn help_subsubcommand() {
               
               [env: UV_MANAGED_PYTHON=]
 
-          --no-managed-python
+      --no-managed-python
               Disable use of uv-managed Python versions.
               
               Instead, uv will search for a suitable Python version on the system.
               
               [env: UV_NO_MANAGED_PYTHON=]
 
-          --no-python-downloads
+      --no-python-downloads
               Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
@@ -728,10 +725,9 @@ fn help_flag_subcommand() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
-          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
-          --no-python-downloads  Disable automatic downloads of Python. [env:
-                                 "UV_PYTHON_DOWNLOADS=never"]
+      --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+      --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+      --no-python-downloads  Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet...
@@ -800,10 +796,9 @@ fn help_flag_subsubcommand() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
-          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
-          --no-python-downloads  Disable automatic downloads of Python. [env:
-                                 "UV_PYTHON_DOWNLOADS=never"]
+      --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+      --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+      --no-python-downloads  Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet...
@@ -956,10 +951,9 @@ fn help_with_global_option() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
-          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
-          --no-python-downloads  Disable automatic downloads of Python. [env:
-                                 "UV_PYTHON_DOWNLOADS=never"]
+      --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+      --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+      --no-python-downloads  Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet...
@@ -1071,10 +1065,9 @@ fn help_with_no_pager() {
           --cache-dir [CACHE_DIR]  Path to the cache directory [env: UV_CACHE_DIR=]
 
     Python options:
-          --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
-          --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
-          --no-python-downloads  Disable automatic downloads of Python. [env:
-                                 "UV_PYTHON_DOWNLOADS=never"]
+      --managed-python       Require use of uv-managed Python versions [env: UV_MANAGED_PYTHON=]
+      --no-managed-python    Disable use of uv-managed Python versions [env: UV_NO_MANAGED_PYTHON=]
+      --no-python-downloads  Disable automatic downloads of Python. [env: "UV_PYTHON_DOWNLOADS=never"]
 
     Global options:
       -q, --quiet...
